==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/EndpointPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.EndpointPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes a container endpoint.
 * @property name The name of the endpoint.
 * @property port Port used by the container.
 */
public data class EndpointPropertiesArgs(
    public val name: Output<String>,
    public val port: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.EndpointPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.EndpointPropertiesArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.EndpointPropertiesArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .port(port?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EndpointPropertiesArgs].
 */
@PulumiTagMarker
public class EndpointPropertiesArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var port: Output<Int>? = null

    /**
     * @param value The name of the endpoint.
     */
    @JvmName("gerwiemnrhkbfgnw")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Port used by the container.
     */
    @JvmName("odewsnuoleygbniy")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value The name of the endpoint.
     */
    @JvmName("jqhlcelgohiwjnad")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Port used by the container.
     */
    @JvmName("yhhtpuespajemqeq")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    internal fun build(): EndpointPropertiesArgs = EndpointPropertiesArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        port = port,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/EndpointPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.EndpointPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes a container endpoint.
 * @property name The name of the endpoint.
 * @property port Port used by the container.
 */
public data class EndpointPropertiesArgs(
    public val name: Output<String>,
    public val port: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.EndpointPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.EndpointPropertiesArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.EndpointPropertiesArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .port(port?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EndpointPropertiesArgs].
 */
@PulumiTagMarker
public class EndpointPropertiesArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var port: Output<Int>? = null

    /**
     * @param value The name of the endpoint.
     */
    @JvmName("grvkdfdiuijplrso")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Port used by the container.
     */
    @JvmName("mjoxihpufpyergmt")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value The name of the endpoint.
     */
    @JvmName("smgrxrdgavsvahol")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Port used by the container.
     */
    @JvmName("phtplmseikdlkhgn")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    internal fun build(): EndpointPropertiesArgs = EndpointPropertiesArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        port = port,
    )
}
